package com.yixin.ms.controller;


import com.yixin.ms.boot.restful.RestResponse;
import com.yixin.ms.boot.restful.RestResult;
import com.yixin.ms.boot.restful.ServiceException;
import com.yixin.ms.boot.uitls.SMSOrIdCardUtils;
import com.yixin.ms.model.dto.HealthCodeDTO;
import com.yixin.ms.model.dto.ShortTermDTO;
import com.yixin.ms.model.vo.HealtCodeUserVO;
import com.yixin.ms.server.vo.HealthCodeVO;
import com.yixin.ms.service.HealthCodeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.bind.annotation.*;


@Slf4j
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
@Api(tags = "健康码查询 API")
@RestController
@RequestMapping("hh")
public class HealthCodeController {
    /**
     * 服务对象
     */
    private final HealthCodeService healthCodeService;

    @ApiOperation("查询")
    @PostMapping("/getHealthCode")
    public RestResult<HealtCodeUserVO> getShortTermCertificate(@RequestBody ShortTermDTO shortTermDTO) {
        return healthCodeService.getShortTerm(shortTermDTO);
    }

    @ApiOperation("创建token")
    @PostMapping("/addToken")
    public RestResult<String> addToken(String token) {
        if (StringUtils.isBlank(token)) {
            throw new ServiceException("token为空哦");
        }
        if (!StringUtils.equals("hanghui", token)) {
            throw new ServiceException("权限不足");
        }
        String shortTermCertificate = healthCodeService.addToken(token);
        if (StringUtils.isNotBlank(shortTermCertificate)) {
            return RestResponse.ok(shortTermCertificate);
        }
        throw new ServiceException(703, "未查询到此数据");
    }

    @ApiOperation("删除token")
    @GetMapping("/deleteToken")
    public RestResult<Boolean> deleteToken(String token) {
        if (StringUtils.isBlank(token)) {
            throw new ServiceException("token为空哦");
        }
        Boolean shortTermCertificate = healthCodeService.deleteToken(token);
        if (shortTermCertificate) {
            return RestResponse.ok(shortTermCertificate);
        }
        throw new ServiceException("删除失败");
    }

    @ApiOperation("根据barcode查询健康码信息")
    @PostMapping("/queryInfoByBarCode")
    public RestResult<HealthCodeVO> queryInfoByBarCode(@RequestBody HealthCodeDTO healthCodeDTO){
        return healthCodeService.queryInfoByBarCode(healthCodeDTO);
    }

}
